# frozen_string_literal: true

module Types
  class VulnerabilityLocationType < BaseUnion
    UnexpectedReportType = Class.new(StandardError)

    graphql_name 'VulnerabilityLocation'
    description 'Represents a vulnerability location. The fields with data will depend on the vulnerability report type'

    possible_types VulnerabilityLocation::ContainerScanningType,
                   VulnerabilityLocation::DependencyScanningType,
                   VulnerabilityLocation::DastType,
                   VulnerabilityLocation::SastType

    def self.resolve_type(object, context)
      case object[:report_type]
      when 'container_scanning'
        VulnerabilityLocation::ContainerScanningType
      when 'dependency_scanning'
        VulnerabilityLocation::DependencyScanningType
      when 'dast'
        VulnerabilityLocation::DastType
      when 'sast'
        VulnerabilityLocation::SastType
      else
        raise UnexpectedReportType, "Report type must be one of #{::Vulnerabilities::Occurrence::REPORT_TYPES.keys}"
      end
    end
  end
end
