# frozen_string_literal: true

require 'spec_helper'

describe 'Query.project(fullPath).vulnerabilitySeveritiesCount' do
  let_it_be(:project) { create(:project) }
  let_it_be(:user) { create(:user) }
  let_it_be(:confirmed_vulnerability) { create(:vulnerability, :confirmed, :high, project: project) }
  let_it_be(:detected_vulnerability) { create(:vulnerability, :detected, :high, project: project) }
  let_it_be(:resolved_vulnerability) { create(:vulnerability, :resolved, :high, project: project) }
  let_it_be(:dismissed_vulnerabilities) { create(:vulnerability, :dismissed, :high, project: project) }

  let_it_be(:query) do
    %(
      query {
        project(fullPath:"#{project.full_path}") {
          vulnerabilitySeveritiesCount {
            high
          }
        }
      }
    )
  end

  before do
    stub_licensed_features(security_dashboard: true)

    project.add_developer(user)
  end

  subject { GitlabSchema.execute(query, context: { current_user: user }).as_json }

  it "returns counts for each severity of the project's detected or confirmed vulnerabilities" do
    high_count = subject.dig('data', 'project', 'vulnerabilitySeveritiesCount', 'high')

    expect(high_count).to be(2)
  end
end
